# chrono - agendas system
# Copyright (C) 2016  Entr'ouvert
#
# This program is free software: you can redistribute it and/or modify it
# under the terms of the GNU Affero General Public License as published
# by the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU Affero General Public License for more details.
#
# You should have received a copy of the GNU Affero General Public License
# along with this program.  If not, see <http://www.gnu.org/licenses/>.

from django.conf.urls import url

from . import views

urlpatterns = [
    url(r'^agenda/$', views.agendas),
    url(r'^agendas/datetimes/$', views.agendas_datetimes, name='api-agendas-datetimes'),
    url(r'^agendas/recurring-events/$', views.recurring_events_list, name='api-agenda-recurring-events'),
    url(r'^agendas/recurring-events/fillslots/$', views.recurring_fillslots, name='api-recurring-fillslots'),
    url(
        r'^agendas/events/fillslots/$',
        views.agendas_events_fillslots,
        name='api-agendas-events-fillslots',
    ),
    url(
        r'^agendas/events/check-status/$',
        views.agendas_events_check_status,
        name='api-agendas-events-check-status',
    ),
    url(r'^agenda/(?P<agenda_identifier>[\w-]+)/$', views.agenda),
    url(r'^agenda/(?P<agenda_identifier>[\w-]+)/datetimes/$', views.datetimes, name='api-agenda-datetimes'),
    url(
        r'^agenda/(?P<agenda_identifier>[\w-]+)/fillslot/(?P<event_identifier>[\w:-]+)/$',
        views.fillslot,
        name='api-fillslot',
    ),
    url(r'^agenda/(?P<agenda_identifier>[\w-]+)/fillslots/$', views.fillslots, name='api-agenda-fillslots'),
    url(
        r'^agenda/(?P<agenda_identifier>[\w-]+)/events/fillslots/$',
        views.events_fillslots,
        name='api-agenda-events-fillslots',
    ),
    url(
        r'^agenda/(?P<agenda_identifier>[\w-]+)/event/$',
        views.events,
        name='api-events',
    ),
    url(
        r'^agenda/(?P<agenda_identifier>[\w-]+)/event/(?P<event_identifier>[\w:-]+)/$',
        views.event,
        name='api-event',
    ),
    url(
        r'^agenda/(?P<agenda_identifier>[\w-]+)/status/(?P<event_identifier>[\w:-]+)/$',
        views.event_status,
        name='api-event-status',
    ),
    url(
        r'^agenda/(?P<agenda_identifier>[\w-]+)/bookings/(?P<event_identifier>[\w:-]+)/$',
        views.event_bookings,
        name='api-event-bookings',
    ),
    url(
        r'^agenda/(?P<agenda_identifier>[\w-]+)/check/(?P<event_identifier>[\w:-]+)/$',
        views.event_check,
        name='api-event-check',
    ),
    url(
        r'^agenda/meetings/(?P<meeting_identifier>[\w-]+)/datetimes/$',
        views.meeting_datetimes,
        name='api-agenda-meeting-datetimes-legacy',
    ),
    url(r'^agenda/(?P<agenda_identifier>[\w-]+)/meetings/$', views.meeting_list, name='api-agenda-meetings'),
    url(
        r'^agenda/(?P<agenda_identifier>[\w-]+)/meetings/(?P<meeting_identifier>[\w-]+)/$',
        views.meeting_info,
        name='api-agenda-meetings',
    ),
    url(
        r'^agenda/(?P<agenda_identifier>[\w-]+)/resources/$',
        views.agenda_resource_list,
        name='api-agenda-resources',
    ),
    url(r'^agenda/(?P<agenda_identifier>[\w-]+)/desks/$', views.agenda_desk_list, name='api-agenda-desks'),
    url(
        r'^agenda/(?P<agenda_identifier>[\w-]+)/meetings/(?P<meeting_identifier>[\w-]+)/datetimes/$',
        views.meeting_datetimes,
        name='api-agenda-meeting-datetimes',
    ),
    url(
        r'^agenda/(?P<agenda_identifier>[\w-]+)/subscription/$',
        views.subscriptions,
        name='api-agenda-subscriptions',
    ),
    url(
        r'^agenda/(?P<agenda_identifier>[\w-]+)/subscription/(?P<subscription_pk>\d+)/$',
        views.subscription,
        name='api-agenda-subscription',
    ),
    url(r'^bookings/$', views.bookings, name='api-bookings'),
    url(r'^booking/(?P<booking_pk>\d+)/$', views.booking, name='api-booking'),
    url(r'^booking/(?P<booking_pk>\d+)/cancel/$', views.cancel_booking, name='api-cancel-booking'),
    url(r'^booking/(?P<booking_pk>\d+)/accept/$', views.accept_booking, name='api-accept-booking'),
    url(r'^booking/(?P<booking_pk>\d+)/anonymize/$', views.anonymize_booking, name='api-anonymize-booking'),
    url(r'^booking/(?P<booking_pk>\d+)/suspend/$', views.suspend_booking, name='api-suspend-booking'),
    url(r'^booking/(?P<booking_pk>\d+)/resize/$', views.resize_booking, name='api-resize-booking'),
    url(r'^booking/(?P<booking_pk>\d+)/ics/$', views.booking_ics, name='api-booking-ics'),
    url(r'^shared-custody/$', views.shared_custody_agendas, name='api-shared-custody-agendas'),
    url(
        r'^shared-custody/(?P<agenda_pk>\d+)/add-child/$',
        views.shared_custody_agenda_add_child,
        name='api-shared-custody-agenda-add-child',
    ),
    url(r'^statistics/$', views.statistics_list, name='api-statistics-list'),
    url(r'^statistics/bookings/$', views.bookings_statistics, name='api-statistics-bookings'),
]
